/* file lex_ind_str1.h             */
/* lexicon index structure # 1     */
/* parameterized by MAX_LEX_FILES  */
/* updated 12/11/97 by WMF to optionally hold all items in a Pronlex */

#include "lex_constants.h"

#if !defined(LEX_IND_STR1_HEADER)
#define LEX_IND_STR1_HEADER

 typedef struct
   {char *name;
    char *first_item;
    char *last_item;
    int nitems;
   } LEX_FILE;

 typedef struct
   {char *fname;
    char *dir;
    char *format; /* "UCLA1", "BU", etc. */
    char *mode; /* nc = no comments in file */
    char *fname_orth_pcode;
    char *fname_phon_pcode;
    pcodeset *orth_pcode;
    pcodeset *phon_pcode;
    boolean copiable;
    boolean no_comments; /* T iff no comments are in the files */
    int nlfiles;
    LEX_FILE lfile[MAX_LEX_FILES];
    int max_nitems;
    int nitems;
    boolean items_present;
    double total_freq;
    LEX_ITEM3 **entry; /* dynamically allocated table of pointers */
   } LEX_FILE_INDEX;

#endif
