/* file lex_constants.h */
/* Compile-time constants for lexicon software.              */
/* for now, each compile-time constant is protected by "#if" */
/* so that it can be re-set at the head of a C module that   */
/* includes this file.                                       */

#if !defined(MAX_LEX_FILES)
#define MAX_LEX_FILES 200
#endif

#if !defined(MAX_ITEM_LENGTH)
#define MAX_ITEM_LENGTH 12000
#endif

#if !defined(MAX_ORTH_PER_KEY)
#define MAX_ORTH_PER_KEY  40
#endif

#if !defined(MAX_LEX_ITEMS)
#define MAX_LEX_ITEMS 10000
#endif
