/* file critstr1.h */
/* Complex specification of criteria for match */

#if !defined(CRITSTR1_HEADER)
#define CRITSTR1_HEADER

 struct CRIT_SPEC
   {int k ; /* general threshold */
    boolean equal_sets_of_prons;
    boolean prons_occur_N_times;
   };

#endif
