/* file plex/lexpars.h */
#if !defined(PRON_CONSTANTS)
#define PRON_CONSTANTS
#define MAX_PRONS 32
#define MAX_PRONS_PER_ITEM 400
#define MAX_INPUT_CRDS 12
#define MAX_SYLBS 24
#define MAX_SEGS 120
#define MAX_LECTS 12
#define MAX_RATE 5
#define MIN_RATE 1
#endif
