/* file conspace.c */

#if !defined(COMPILE_ENVIRONMENT)
#include <gp/stdcenvf.h> /* std compile environment for functions */
#endif

boolean contains_whitespace(char *token)
/* Returns T if *token contains whitespace */
{boolean hit; char *sx;
 hit = F;
 for (sx = token; (!hit)&&(*sx != '\0'); sx++)
  if (isspace((int)*sx)) hit = T;
 return hit;
}
