/* file random.h                             */
/* declaration of SUN OS function "random()" */
/* created by WMF 1/15/97                    */

#ifndef RANDOM_HEADER
#define RANDOM_HEADER

extern long int random(void);

#endif
/* end file random.h        */

