/*******************************************/
/* file plex/stdcenvp.h                 */
/* plex compile environment for programs*/
/*******************************************/

#define LEX_COMPILE_ENVIRONMENT 1

/* program parameter settings */
#include "lexpars.h"

#include "lex_constants.h"

/* type definitions */
#include "lexstr1.h"
#include "lexstr2.h"
#include "lexitemstr3.h"
#include "lex_ind_str1.h"
#include "critstr1.h"
#include "pron2.h"
#include "cortabstr2.h"

/* macros */

/* global data declarations (NOT definitions) */
#include "lex_glob_data.h"

/* function declarations */
#include "fcndcls.h"
