/* file lexitemstr3.h */
/* lexical entry w/multiple tagged & categorized prons */

#include "lexpars.h"

#if !defined(LEX_ITEM3_HEADER)
#define LEX_ITEM3_HEADER

/* definition of PRON_SPEC: */
#include "pronstr1.h"

 typedef struct
   {char *key;
    char *orth;
    char *tags;
    char *status;
    double freq;
    int nprons;
    struct PRON_SPEC pron[MAX_PRONS_PER_ITEM+1]; /* one-based */
   } LEX_ITEM3;

#endif
