/* file lexstr1.h */
/* simple lexicon structure #1 */

#if !defined(LEXSTR1_HEADER)
#define LEXSTR1_HEADER

    struct LEX_ITEM1 { char *ps; int freq; };
    struct LEXSTR1
      {int nitems;
       long int ntokens;
       char sorted;
       struct LEX_ITEM1 entry[MAX_LEX_ITEMS+1];
      };

#endif
