/* file lexstr2.h */
/* simple lexicon structure #2 */
/* for keeping ordered word lists */

#if !defined(LEXSTR2_HEADER)
#define LEXSTR2_HEADER

    struct LEX_ITEM2
      {char *sp;
       double value;
      };
    struct LEXSTR2
      {int nitems;
       int nitems_arb_lim;
       int MAX_LEX2_ITEMS;
     /* indexable table, to be dynamically allocated: */
       struct LEX_ITEM2 *entry;
      };

#endif
