 /* File possible_mandarin_byte.c */

#if !defined(COMPILE_ENVIRONMENT)
#include <gp/stdcenvf.h> /* std compile environment for functions */
#endif

 boolean possible_mandarin_byte(char *p)
 /**********************************************************************/
 /*                                                                    */
 /* Returns T iff *p is a possible byte of a 2-byte integer GD Hanzi.  */
 /*                                                                    */
 /**********************************************************************/
 {
/* local data: */
  char *proc = "possible_mandarin_byte";
  boolean ok;
/* code: */
 db_enter_msg(proc,3); /* debug only */
  if (hi_order_bit_set(*p)
    || ((*p == 'T')&&(hi_order_bit_set(*(p+1)))))
    ok = T;
  else ok = F;
 db_leave_msg(proc,3); /* debug only */
   return ok;
  } /* end of function "possible_mandarin_byte" */
